/*
 *  Copyright (C) 2009  Giorgio Wicklein <g.wicklein@giowisys.com> 
 *  
 *  This file is part of Kontakter.
 *
 *  Kontakter is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Kontakter is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Kontakter.  If not, see <http://www.gnu.org/licenses/>.
 */

/* This widget is the core of MainWidget. It handles the form values
 * by connecting with the database, it handles search results, and more...
 * This widget catches the selectionChanged slot emitted by ContactListWidget
 * to call the database and update the form.
 */

#ifndef ADDRESSWIDGET_H
#define ADDRESSWIDGET_H

#include <QWidget>
#include <QtSql>

class QLabel;
class QGridLayout;
class QLineEdit;
class QPlainTextEdit;
class QHBoxLayout;
class QVBoxLayout;
class QPushButton;
class QToolButton;
class QSqlDatabase;
class MainWidget;
class MainWindow;
class PassWidget;

class AddressWidget : public QWidget
{
    Q_OBJECT

public:
    AddressWidget(QWidget *parent = 0);
    bool prepareContactsDB();
    bool loadContactsDB();
    void print(int mode, bool pdf);
    void exportvCard(bool all);
    void clearContactWidget();

    QSqlDatabase *db;
    bool *validPass;

signals:
    void editModeSignal(bool activated);
    void addContactListSignal(QString name);
    void updateActionsSignal();

public slots:
    void addCustomEditField();
    void addContact();
    void editContactSlot();
    void searchSlot(QString searchText);
    void importvCard();

private slots:
    void cancelEditSlot();
    void saveEditSlot();
    void handleRemoveCustom();
    void selectionChangedSlot();
    void mapButtonSlot();
    void emailButtonSlot();
    void webButtonSlot();
    void setEditable(bool editable);
    void deleteContactSlot();
    void checkPassSlot();
    void passCancelSlot();

private:
    void createControls();
    void createCustomControls(); 
    bool addContactToDB();
    bool addEdittedContactToDB();   
    void saveEdittedContact();
    void checkPass();

    QLabel *contactLabel;
    QLabel *workLabel;
    QLabel *homeLabel;
    QLabel *mobileLabel;
    QLabel *addressLabel;
    QLabel *zipLabel;
    QLabel *townLabel;
    QLabel *email1Label;
    QLabel *webLabel;
    QLabel *noteLabel;
    QLineEdit *nameLineEdit;
    QLineEdit *firstNameLineEdit;
    QLineEdit *homeLineEdit;
    QLineEdit *workLineEdit;
    QLineEdit *mobileLineEdit;
    QLineEdit *addressLineEdit;
    QLineEdit *zipLineEdit;
    QLineEdit *townLineEdit;
    QLineEdit *email1LineEdit;
    QLineEdit *webLineEdit;
    QPlainTextEdit *noteTextEdit;
    QGridLayout *mainLayout;
    QVBoxLayout *customLayout;
    QHBoxLayout *editButtonsLayout;
    QPushButton *addButton;
    QToolButton *saveButton;
    QToolButton *cancelButton;
    QToolButton *mapButton;
    QToolButton *emailButton;
    QToolButton *webButton;

    QLineEdit *customLabelEdit1;
    QLineEdit *customLabelEdit2;
    QLineEdit *customLabelEdit3;
    QLineEdit *customLabelEdit4;
    QLineEdit *customLabelEdit5;
    QLineEdit *customLabelEdit6;
    QLineEdit *customValueEdit1;
    QLineEdit *customValueEdit2;
    QLineEdit *customValueEdit3;
    QLineEdit *customValueEdit4;
    QLineEdit *customValueEdit5;
    QLineEdit *customValueEdit6;
    QToolButton *deleteToolButton1;
    QToolButton *deleteToolButton2;
    QToolButton *deleteToolButton3;
    QToolButton *deleteToolButton4;
    QToolButton *deleteToolButton5;
    QToolButton *deleteToolButton6;
    QHBoxLayout *customLayout1;
    QHBoxLayout *customLayout2;
    QHBoxLayout *customLayout3;
    QHBoxLayout *customLayout4;
    QHBoxLayout *customLayout5;
    QHBoxLayout *customLayout6;

//// these are necessary to control custom fields
    QVector<QToolButton*> *deleteToolButtonsVec;
    QVector<QLineEdit*> *lineLabelEditsVec;
    QVector<QLineEdit*> *lineEditsVec;
    int *customCount;
    int *currentCustomCount;

    MainWidget *mw;
    MainWindow *mainWindow;
    PassWidget *passWidget;

//// used to verify if the user is editing a contact
    bool *editContact;

//// selectedContactId stores the id (from database)
//// of the selected contact
//// it is used to keep track of a contact
//// when firstName and/or name are changed
//// so it is possible to update the database entry
//// because the id never changes :)
    quint64 *selectedContactId;
};

#endif // ADDRESSWIDGET_H
