/*
 *  Copyright (C) 2009  Giorgio Wicklein <g.wicklein@giowisys.com> 
 *  
 *  This file is part of Kontakter.
 *
 *  Kontakter is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Kontakter is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Kontakter.  If not, see <http://www.gnu.org/licenses/>.
 */

/* The MainWindow class is the main widget shown when the application runs.
 * Too complex to describe here :P
 */

#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include <QMainWindow>
#include <QSystemTrayIcon>
#include <QTcpSocket>

class QAction;
class QLabel;
class QToolBar;
class QMenu;
class QStackedWidget;
class QVBoxLayout;
class QMenu;
class QActionGroup;
class MainWidget;
class SettingsWidget;
class PrintWidget;
class NewAccountWidget;
class QHttp;

class MainWindow : public QMainWindow
{
    Q_OBJECT

public:
    MainWindow();
    void disableAll(bool d);
    bool connectToServer();
    bool isRevUpToDate();
    void disconnectFromServer();
    void incrementLocalRevision();
    void disableSyncAction();

    QString *currentDatabase;
    SettingsWidget *settingsWidget;
    QString *version;
    QString *localServerPass;
    QString accountType;
    quint64 localRevision;
    QTcpSocket *tcpSocket;

public slots:
    void updateActions();
    void newAccountCancSlot();

protected:
    void closeEvent(QCloseEvent *event);

private slots:
    void handleEditModeSlot(bool activated);
    void settingsActionSlot();
    void printActionSlot();
    void trayActivated(QSystemTrayIcon::ActivationReason reason);
    void newAccountCompleteSlot();
    void handleQuitSlot();
    void newAccountSlot();
    void deleteAccountSlot();
    void accountChangeSlot();
    void printSlot();
    void exportSelectedPdf();
    void exportAllPdf();
    void exportDatabase();
    void exportvCardSelSlot();
    void exportvCardAllSlot();
    void importDatabase();
    void documentationSlot();
    void updateSlot();
    void updateDoneSlot(bool error);
    void loadAccountSettings();
    void aboutSlot();
    void reportBugSlot();
    void askSlot();
    void featureRequestSlot();
    void socketError();
    void syncDatabase();

private:
    void checkFirstRun();
    void checkDate();
    void createActions();
    void createMenus();
    void createToolBar();
    void createStatusBar();
    void writeSettings();
    void readSettings();
    void createTrayIcon();
    void createConnections();
    void updateAccountsMenu();
    void checkUpdates();
    void helloServer();
    void goodbyeServer();

    QAction *newContactAction;
    QAction *editContactAction;
    QAction *deleteContactAction;
    QAction *syncContactsAction;
    QAction *settingsAction;
    QAction *printAction;
    QAction *exitAction;
    QAction *showAction;
    QAction *hideAction;
    QAction *newAccountAction;
    QAction *deleteAccountAction;
    QAction *exportSelectedPdfAction;
    QAction *exportAllPdfAction;
    QAction *exportDatabaseAction;
    QAction *exportvCardSelAction;
    QAction *exportvCardAllAction;
    QAction *importDatabaseAction;
    QAction *importvCardAction;
    QAction *aboutQtAction;
    QAction *aboutAction;
    QAction *documentationAction;
    QAction *updateAction;
    QAction *reportBugAction;
    QAction *askAction;
    QAction *featureRequestAction;
    QActionGroup *accountActionGroup;
    QMenu *fileMenu;
    QMenu *editMenu;
    QMenu *accountsMenu;
    QMenu *exportMenu;
    QMenu *importMenu;
    QMenu *pdfMenu;
    QMenu *vCardMenu;
    QMenu *helpMenu;
    QToolBar *toolBar;
    QStackedWidget *stackedWidget;
    QVBoxLayout *mainLayout;
    QSystemTrayIcon *trayIcon;
    QMenu *trayMenu;
    MainWidget *mainWidget;
    PrintWidget *printWidget;
    NewAccountWidget *newAccountWidget;
    bool *settingsWidgetActive;
    bool *printWidgetActive;
    QList<QAction*> *accountsActionList;
    int *buildNumber;
    QHttp *http;
    bool *firstRun;
};

#endif // MAINWINDOW_H
