/*
 *  Copyright (C) 2009  Giorgio Wicklein <g.wicklein@giowisys.com> 
 *  
 *  This file is part of Kontakter.
 *
 *  Kontakter is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Kontakter is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Kontakter.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <QtGui>

#include "networkpage.h"

NetworkPage::NetworkPage(QWidget *parent) : QWidget(parent)
{
    hostLabel = new QLabel(tr("Host: "), this);
    portLabel = new QLabel(tr("Port: "), this);
    passLabel = new QLabel(tr("Password: "), this);


    hostLineEdit = new QLineEdit(this);
    hostLineEdit->setText("127.0.0.1");
    hostLineEdit->setToolTip(tr("Host/IP address of the server"));
    hostLineEdit->setInputMask("000.000.000.000;");

    passLineEdit = new QLineEdit(this);
    passLineEdit->setEchoMode(QLineEdit::Password);
    passLineEdit->setToolTip(tr("Server's password"));

    portSpinBox = new QSpinBox(this);
    portSpinBox->setRange(60, 65535);
    portSpinBox->setValue(1337);
    portSpinBox->setToolTip(tr("The port where the server is listening (Default 1337)"));

    nextButton = new QPushButton(tr("&Next"), this);
    cancelButton = new QPushButton(tr("&Cancel"), this);

    nextButton->setEnabled(false);

    serverGroupBox = new QGroupBox(tr("Server settings"), this);

    mainLayout = new QVBoxLayout;
    buttonsLayout = new QHBoxLayout;
    serverLayout = new QGridLayout;

    buttonsLayout->addWidget(cancelButton);
    buttonsLayout->addWidget(nextButton);
    serverLayout->addWidget(hostLabel, 0, 0);
    serverLayout->addWidget(hostLineEdit, 0, 1);
    serverLayout->addWidget(portLabel, 1, 0);
    serverLayout->addWidget(portSpinBox, 1, 1);
    serverLayout->addWidget(passLabel, 2, 0);
    serverLayout->addWidget(passLineEdit, 2, 1);

    serverGroupBox->setLayout(serverLayout);

    mainLayout->addWidget(serverGroupBox);
    mainLayout->addLayout(buttonsLayout);

    setLayout(mainLayout);

    connect(cancelButton, SIGNAL(clicked()), this, SIGNAL(cancelSignal()));
    connect(nextButton, SIGNAL(clicked()), this, SIGNAL(createNetworkAccountSignal()));
    connect(hostLineEdit, SIGNAL(textChanged(QString)), this, SLOT(updateNextButtonSlot()));
    connect(passLineEdit, SIGNAL(textChanged(QString)), this, SLOT(updateNextButtonSlot()));
}

void NetworkPage::updateNextButtonSlot()
{
    if ((hostLineEdit->text().isEmpty()) || (passLineEdit->text().isEmpty()))
        nextButton->setEnabled(false);
    else
        nextButton->setEnabled(true);
}
