/*
 *  Copyright (C) 2009  Giorgio Wicklein <g.wicklein@giowisys.com> 
 *  
 *  This file is part of Kontakter.
 *
 *  Kontakter is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Kontakter is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Kontakter.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <QtGui>

#include "page_1.h"

/* _________________________________PUBLIC__________________________________ */

//// constructor
Page_1::Page_1(QWidget *parent) : QWidget(parent)
{

//// account name
    accountNameLabel = new QLabel(tr("Account Name: "), this);
    accountLineEdit = new QLineEdit(this);

//// help button
    helpToolButton = new QToolButton(this);
    helpToolButton->setIcon(QIcon(":/icons/help.png"));
    helpToolButton->setIconSize(QSize(32, 32));

//// password
    passCheckBox = new QCheckBox(tr("Use password protection"), this);
    passLineEdit = new QLineEdit(this);
    passLineEdit->setEchoMode(QLineEdit::Password);
    passLineEdit->setEnabled(false);

//// control buttons
    cancelButton = new QPushButton(tr("&Cancel"), this);
    nextButton = new QPushButton(tr("&Next >"), this);
    nextButton->setEnabled(false);

//// account type
    typeGroupBox = new QGroupBox(this);
    accountTypeLabel = new QLabel(tr("Account Type: "), this);
    localRadioButton = new QRadioButton(tr("Local"), this);
    networkRadioButton = new QRadioButton(tr("Network"), this);

//// connections
    connect(cancelButton, SIGNAL(clicked()), this, SIGNAL(cancelSignal()));
    connect(helpToolButton, SIGNAL(clicked()),
            this, SLOT(helpToolButtonSlot()));
    connect(passCheckBox, SIGNAL(toggled(bool)),
            passLineEdit, SLOT(setEnabled(bool)));
    connect(nextButton, SIGNAL(clicked()), this, SIGNAL(nextSignal()));
    connect(accountLineEdit, SIGNAL(textChanged(QString)),
            this, SLOT(updateNextButtonSlot()));
    connect(passCheckBox, SIGNAL(toggled(bool)),
            this, SLOT(updateNextButtonSlot()));
    connect(passLineEdit, SIGNAL(textChanged(QString)),
            this, SLOT(updateNextButtonSlot()));

//// layouts
    accountNameLayout = new QHBoxLayout;
    accountNameLayout->addWidget(accountNameLabel);
    accountNameLayout->addWidget(accountLineEdit);

    buttonsLayout = new QHBoxLayout;
    buttonsLayout->addWidget(cancelButton);
    buttonsLayout->addWidget(nextButton);

    typeLayout = new QHBoxLayout;
    typeLayout->addWidget(localRadioButton);
    typeLayout->addWidget(networkRadioButton);

    typeGroupBox->setLayout(typeLayout);

    accountTypeLayout = new QHBoxLayout;
    accountTypeLayout->addWidget(accountTypeLabel);
    accountTypeLayout->addWidget(typeGroupBox);
    accountTypeLayout->addWidget(helpToolButton);

    passLayout = new QHBoxLayout;
    passLayout->addWidget(passCheckBox);
    passLayout->addWidget(passLineEdit);

    mainLayout = new QVBoxLayout;
    mainLayout->addLayout(accountNameLayout);
    mainLayout->addStretch();
    mainLayout->addLayout(accountTypeLayout);
    mainLayout->addLayout(passLayout);
    mainLayout->addLayout(buttonsLayout);

    setLayout(mainLayout);

//// default account type is local
//// WARNING: do not move this
    localRadioButton->setChecked(true);
}

/* _________________________________________________________________________ */
/* ______________________________PRIVATE SLOTS______________________________ */

//// when users click the help button
//// give info about account types
void Page_1::helpToolButtonSlot()
{
    QMessageBox::information(this, tr("Account Types"),
         tr("<h3>Local:</h3> This account type stores your contacts only in a local database."
            "<h3>Network:</h3> This account type synchronizes your contacts with a central database, provided by Kontakter's server."));
}

//// check if the account information are empty
//// if yes then disable the next button
void Page_1::updateNextButtonSlot()
{
    if (accountLineEdit->text().isEmpty()) {
        nextButton->setEnabled(false);
    } else if (passCheckBox->isChecked() && passLineEdit->text().isEmpty()) {
        nextButton->setEnabled(false);
    } else {
        nextButton->setEnabled(true);
    }
}

/* _________________________________________________________________________ */
