/*
 *  Copyright (C) 2009  Giorgio Wicklein <g.wicklein@giowisys.com> 
 *  
 *  This file is part of Kontakter.
 *
 *  Kontakter is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Kontakter is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Kontakter.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <QtGui>

#include "passwidget.h"

/* _________________________________PUBLIC__________________________________ */

//// constructor
PassWidget::PassWidget(QWidget *parent) : QWidget(parent)
{
//// main message
    mainLabel = new QLabel(tr("<h3>This account is password protected!</h3>"),
                           this);
//// password
    passLabel = new QLabel(tr("Password: "), this);
    passLineEdit = new QLineEdit(this);
    passLineEdit->setEchoMode(QLineEdit::Password);

//// main controls
    cancelButton = new QPushButton(tr("Cancel"), this);
    validateButton = new QPushButton(tr("Validate"), this);

//// it is disabled to avoid empty password bypass
    validateButton->setEnabled(false);

//// layouts
    passLayout = new QHBoxLayout;
    buttonsLayout = new QHBoxLayout;
    mainLayout = new QVBoxLayout;

    passLayout->addWidget(passLabel);
    passLayout->addWidget(passLineEdit);

    buttonsLayout->addStretch();
    buttonsLayout->addWidget(cancelButton);
    buttonsLayout->addWidget(validateButton);

    mainLayout->addWidget(mainLabel);
    mainLayout->addLayout(passLayout);
    mainLayout->addLayout(buttonsLayout);

    setLayout(mainLayout);

//// set widget non resizable
    layout()->setSizeConstraint(QLayout::SetFixedSize);

    setWindowTitle(tr("Password request"));

//// Until password widget is alive, block access to other windows
    setWindowModality(Qt::ApplicationModal);

//// connections
    connect(passLineEdit, SIGNAL(textChanged(QString)),
            this, SLOT(updateButtonsSlot()));
}

/* _________________________________________________________________________ */
/* _________________________________EVENTS__________________________________ */

void PassWidget::closeEvent(QCloseEvent *event)
{
    event->ignore();
}

/* _________________________________________________________________________ */
/* ______________________________PRIVATE SLOTS______________________________ */

//// This slot handles empty password input by disabling the validate button
//// to avoid empty password bypass
void PassWidget::updateButtonsSlot()
{
    if (passLineEdit->text().isEmpty()) {
        validateButton->setEnabled(false);
    }
    else {
        validateButton->setEnabled(true);
    }
}

/* _________________________________________________________________________ */
