/*
 *  Copyright (C) 2009  Giorgio Wicklein <g.wicklein@giowisys.com> 
 *  
 *  This file is part of Kontakter.
 *
 *  Kontakter is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Kontakter is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Kontakter.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <QtGui>

#include "printwidget.h"
#include "mainwindow.h"

/* _________________________________PUBLIC__________________________________ */

//// constructor
PrintWidget::PrintWidget(QWidget *parent) : QWidget(parent)
{
//// main message
    mainLabel = new QLabel(tr("<h3>What do you want to print?</h3>"), this);
    mainLabel->setAlignment(Qt::AlignHCenter | Qt::AlignBottom);

//// print selected contact
    selectedRadioButton = new QRadioButton(tr("Selected contact: "), this);
    contactName = new QLineEdit(this);
    contactName->setReadOnly(true);

//// print all contacts
    allRadioButton = new QRadioButton(tr("All contacts"), this);

//// this group box contains the 2 radio buttons
//// to choose what to print
    optionsBox = new QGroupBox(this);

//// main controls
    backButton = new QPushButton(tr("Back"), this);
    printButton = new QPushButton(tr("&Print"), this);
    printButton->setDefault(true);

//// layouts
    mainLayout = new QVBoxLayout;
    buttonsLayout = new QHBoxLayout;
    selectedLayout = new QHBoxLayout;
    groupLayout = new QVBoxLayout;

    selectedLayout->addWidget(selectedRadioButton);
    selectedLayout->addWidget(contactName);

    buttonsLayout->addStretch();
    buttonsLayout->addWidget(backButton);
    buttonsLayout->addWidget(printButton);
    buttonsLayout->addStretch();

    groupLayout->addLayout(selectedLayout);
    groupLayout->addWidget(allRadioButton);

    optionsBox->setLayout(groupLayout);

    mainLayout->addWidget(mainLabel);
    mainLayout->addWidget(optionsBox);
    mainLayout->addLayout(buttonsLayout);

    setLayout(mainLayout);

//// default is to print only the selected contact
//// WARNING: do not move this
    selectedRadioButton->setChecked(true);

//// pointer to MainWindow, to have access to its slots
    mW2 = qobject_cast<MainWindow*>(parentWidget());

//// connections
    connect(backButton, SIGNAL(clicked()), mW2, SLOT(printActionSlot()));
    connect(printButton, SIGNAL(clicked()), mW2, SLOT(printSlot()));
}

/* _________________________________________________________________________ */
