/*
 *  Copyright (C) 2009  Giorgio Wicklein <g.wicklein@giowisys.com>
 *
 *  This file is part of Kontakter.
 *
 *  Kontakter is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Kontakter is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Kontakter.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include <QMainWindow>
#include <QSystemTrayIcon>

class QAction;
class QMenu;
class Server;
class ServerWidget;

class MainWindow : public QMainWindow
{
    Q_OBJECT

public:
    MainWindow();

    ServerWidget *serverWidget;

protected:
    void closeEvent(QCloseEvent *);

private slots:
    void quitSlot();
    void startSlot();
    void stopSlot();
    void documentationSlot();
    void trayActivated(QSystemTrayIcon::ActivationReason reason);
    void resetDatabaseSlot();
    void exportDbSlot();
    void importDbSlot();

private:
    void createActions();
    void createMenus();
    void createConnections();
    void createStatusBar();
    void createTrayIcon();
    void readSettings();
    void writeSettings();
    bool isClientConnected();
    void checkFirstRun();


    QAction *exitAction;
    QAction *documentationAction;
    QAction *showAction;
    QAction *hideAction;
    QAction *resetDbAction;
    QAction *importDbAction;
    QAction *exportDbAction;
    QMenu *fileMenu;
    QMenu *editMenu;
    QMenu *helpMenu;
    QMenu *trayMenu;
    QSystemTrayIcon *trayIcon;
    Server *kontakterServer;
};

#endif // MAINWINDOW_H
