/*
 *  Copyright (C) 2009  Giorgio Wicklein <g.wicklein@giowisys.com>
 *
 *  This file is part of Kontakter.
 *
 *  Kontakter is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Kontakter is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Kontakter.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <QtGui>
#include <QtSql>

#include "server.h"
#include "serverthread.h"
#include "mainwindow.h"
#include "serverwidget.h"

Server::Server(QObject *parent) : QTcpServer(parent)
{
    mainWindow = qobject_cast<MainWindow*>(this->parent());
}

void Server::incomingConnection(int socketDescriptor)
{
    ServerThread *thread = new ServerThread(socketDescriptor, this);
    connect(thread, SIGNAL(finished()), thread, SLOT(deleteLater()));
    connect(thread, SIGNAL(error(QString)), this, SLOT(socketErrorSlot(QString)));
    connect(thread, SIGNAL(newClientSignal()), this, SLOT(newClientSlot()));
    connect(thread, SIGNAL(removeClientSignal()), this, SLOT(removeClientSlot()));
    connect(thread, SIGNAL(addContactSignal(QByteArray)), this, SLOT(addContactSlot(QByteArray)));
    connect(thread, SIGNAL(delContactSignal(QByteArray)), this, SLOT(delContactSlot(QByteArray)));
    connect(thread, SIGNAL(editContactSignal(QByteArray)), this, SLOT(editContactSlot(QByteArray)));
    thread->start();
}

void Server::socketErrorSlot(QString socketError)
{
    QMessageBox::critical(mainWindow, tr("Socket error"), socketError);
}

void Server::newClientSlot()
{
    int current = mainWindow->serverWidget->usersLabel->text().toInt();
    ++current;
    mainWindow->serverWidget->usersLabel->setText(QString::number(current));
}

void Server::removeClientSlot()
{
    int current = mainWindow->serverWidget->usersLabel->text().toInt();
    --current;
    mainWindow->serverWidget->usersLabel->setText(QString::number(current));
}

void Server::addContactSlot(QByteArray data)
{
    QDataStream newContact(&data, QIODevice::ReadOnly);
    newContact.setVersion(QDataStream::Qt_4_5);

    QString name, firstName, work, home, mobile, address, zip, town, email, web, note;
    int customCount;
    QString customLabel1, customValue1, customLabel2, customValue2, customLabel3, customValue3,
            customLabel4, customValue4, customLabel5, customValue5, customLabel6, customValue6;

    newContact >> name >> firstName >> work >> home >> mobile >> address >> zip >> town >> email
               >> web >> note >> customCount >> customLabel1 >> customValue1 >> customLabel2 >> customValue2
               >> customLabel3 >> customValue3 >> customLabel4 >> customValue4 >> customLabel5 >> customValue5
               >> customLabel6 >> customValue6;

    QString path = QDir::homePath() + "/.Kontakter/server/";
    QSqlDatabase db(QSqlDatabase::addDatabase("QSQLITE"));
    db.setDatabaseName(path + "server.sqlite");

    if (!db.open()) {
        QMessageBox::critical(0, tr("Database Error"),
                              db.lastError().text());
        return;
    }

    /* the brackets are necessary to close correctly the database */
    {
        QSqlQuery query;

    query.prepare(
            "INSERT INTO contacts (name, firstName, work, home, mobile, address, zip, town, email, web, notes, customCount, customLabel1, customValue1, customLabel2, customValue2, customLabel3, customValue3, customLabel4, customValue4, customLabel5, customValue5, customLabel6, customValue6, date) "
            "VALUES (:name, :firstName, :work, :home, :mobile, :address, :zip, :town, :email, :web, :notes, :customCount, :customLabel1, :customValue1, :customLabel2, :customValue2, :customLabel3, :customValue3, :customLabel4, :customValue4, :customLabel5, :customValue5, :customLabel6, :customValue6, CURRENT_TIMESTAMP)"
            );
    query.bindValue(":name", name);
    query.bindValue(":firstName", firstName);
    query.bindValue(":work", work);
    query.bindValue(":home", home);
    query.bindValue(":mobile", mobile);
    query.bindValue(":address", address);
    query.bindValue(":zip", zip);
    query.bindValue(":town", town);
    query.bindValue(":email", email);
    query.bindValue(":web", web);
    query.bindValue(":notes", note);
    query.bindValue(":customCount", customCount);
    query.bindValue(":customLabel1", customLabel1);
    query.bindValue(":customValue1", customValue1);
    query.bindValue(":customLabel2", customLabel2);
    query.bindValue(":customValue2", customValue2);
    query.bindValue(":customLabel3", customLabel3);
    query.bindValue(":customValue3", customValue3);
    query.bindValue(":customLabel4", customLabel4);
    query.bindValue(":customValue4", customValue4);
    query.bindValue(":customLabel5", customLabel5);
    query.bindValue(":customValue5", customValue5);
    query.bindValue(":customLabel6", customLabel6);
    query.bindValue(":customValue6", customValue6);
    query.exec();
    }

    db.close();
    db.removeDatabase("QSQLITE");
}

void Server::delContactSlot(QByteArray data)
{
    QDataStream delContact(&data, QIODevice::ReadOnly);
    delContact.setVersion(QDataStream::Qt_4_5);

    QString name, firstName;

    delContact >> name >> firstName;

    QString path = QDir::homePath() + "/.Kontakter/server/";
    QSqlDatabase db(QSqlDatabase::addDatabase("QSQLITE"));
    db.setDatabaseName(path + "server.sqlite");

    if (!db.open()) {
        QMessageBox::critical(0, tr("Database Error"),
                              db.lastError().text());
        return;
    }

    /* the brackets are necessary to close correctly the database */
    {
        QSqlQuery query;

        query.prepare("DELETE FROM contacts WHERE name=:name AND firstName=:firstName");
        query.bindValue(":name", name);
        query.bindValue(":firstName", firstName);
        query.exec();
    }

    db.close();
    db.removeDatabase("QSQLITE");
}

void Server::editContactSlot(QByteArray data)
{
    QDataStream editContact(&data, QIODevice::ReadOnly);
    editContact.setVersion(QDataStream::Qt_4_5);

    QString name, firstName, work, home, mobile, address, zip, town, email, web, note;
    int customCount;
    QString customLabel1, customValue1, customLabel2, customValue2, customLabel3, customValue3,
            customLabel4, customValue4, customLabel5, customValue5, customLabel6, customValue6;
    quint64 contactId;

    editContact >> name >> firstName >> work >> home >> mobile >> address >> zip >> town >> email
               >> web >> note >> customCount >> customLabel1 >> customValue1 >> customLabel2 >> customValue2
               >> customLabel3 >> customValue3 >> customLabel4 >> customValue4 >> customLabel5 >> customValue5
               >> customLabel6 >> customValue6 >> contactId;

    QString path = QDir::homePath() + "/.Kontakter/server/";
    QSqlDatabase db(QSqlDatabase::addDatabase("QSQLITE"));
    db.setDatabaseName(path + "server.sqlite");

    if (!db.open()) {
        QMessageBox::critical(0, tr("Database Error"),
                              db.lastError().text());
        return;
    }

    /* the brackets are necessary to close correctly the database */
    {
        QSqlQuery query;

        query.prepare(
                "UPDATE contacts SET "
                "name=:name, firstName=:firstName, work=:work, home=:home, mobile=:mobile, address=:address, zip=:zip, town=:town, email=:email, web=:web, notes=:notes, customCount=:customCount, customLabel1=:customLabel1, customValue1=:customValue1, customLabel2=:customLabel2, customValue2=:customValue2, customLabel3=:customLabel3, customValue3=:customValue3, customLabel4=:customLabel4, customValue4=:customValue4, customLabel5=:customLabel5, customValue5=:customValue5, customLabel6=:customLabel6, customValue6=:customValue6, date=CURRENT_TIMESTAMP"
                " WHERE id=:id"
                );
    query.bindValue(":name", name);
    query.bindValue(":firstName", firstName);
    query.bindValue(":work", work);
    query.bindValue(":home", home);
    query.bindValue(":mobile", mobile);
    query.bindValue(":address", address);
    query.bindValue(":zip", zip);
    query.bindValue(":town", town);
    query.bindValue(":email", email);
    query.bindValue(":web", web);
    query.bindValue(":notes", note);
    query.bindValue(":customCount", customCount);
    query.bindValue(":customLabel1", customLabel1);
    query.bindValue(":customValue1", customValue1);
    query.bindValue(":customLabel2", customLabel2);
    query.bindValue(":customValue2", customValue2);
    query.bindValue(":customLabel3", customLabel3);
    query.bindValue(":customValue3", customValue3);
    query.bindValue(":customLabel4", customLabel4);
    query.bindValue(":customValue4", customValue4);
    query.bindValue(":customLabel5", customLabel5);
    query.bindValue(":customValue5", customValue5);
    query.bindValue(":customLabel6", customLabel6);
    query.bindValue(":customValue6", customValue6);
    query.bindValue(":id", contactId);
    query.exec();
    }

    db.close();
    db.removeDatabase("QSQLITE");
}
