/*
 *  Copyright (C) 2009  Giorgio Wicklein <g.wicklein@giowisys.com>
 *
 *  This file is part of Kontakter.
 *
 *  Kontakter is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Kontakter is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Kontakter.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <QtGui>

#include "serverwidget.h"

ServerWidget::ServerWidget(QWidget *parent) : QWidget(parent)
{
    passLabel = new QLabel(tr("Password: "), this);
    portLabel = new QLabel(tr("Port: "), this);

    infoUsersLabel = new QLabel(tr("Connected clients: "), this);
    usersLabel = new QLabel(tr("0"), this);

    passLineEdit = new QLineEdit(this);
    passLineEdit->setEchoMode(QLineEdit::Password);
    passLineEdit->setToolTip(tr("This password permits the clients to connect to the server"));

    portSpinBox = new QSpinBox(this);
    portSpinBox->setRange(60, 65535);
    portSpinBox->setValue(1337);
    portSpinBox->setToolTip(tr("The port where the server is listening (Default 1337)"));

    startCheckBox = new QCheckBox(tr("Start server at program start"), this);

    serverGroupBox = new QGroupBox(tr("Server settings"), this);

    startButton = new QPushButton(tr("&Start"), this);
    stopButton = new QPushButton(tr("S&top"), this);
    stopButton->setVisible(false);
    quitButton = new QPushButton(tr("&Quit"), this);

    mainLayout = new QVBoxLayout;
    serverLayout = new QGridLayout;
    buttonsLayout = new QHBoxLayout;
    usersLayout = new QHBoxLayout;

    serverLayout->addWidget(portLabel, 0, 0);
    serverLayout->addWidget(portSpinBox, 0, 1);
    serverLayout->addWidget(passLabel, 1, 0);
    serverLayout->addWidget(passLineEdit, 1, 1);

    serverGroupBox->setLayout(serverLayout);

    usersLayout->addWidget(infoUsersLabel);
    usersLayout->addWidget(usersLabel);
    usersLayout->addStretch();

    buttonsLayout->addWidget(quitButton);
    buttonsLayout->addWidget(startButton);
    buttonsLayout->addWidget(stopButton);

    mainLayout->addWidget(serverGroupBox);
    mainLayout->addWidget(startCheckBox);
    mainLayout->addLayout(usersLayout);
    mainLayout->addStretch();
    mainLayout->addLayout(buttonsLayout);

    setLayout(mainLayout);
}
